# Components

## Audio player

<winter-audio-player title="Ramp wave">
    <source
    src="https://storage.googleapis.com/files.winterbloom.com/gemini/ramp_octaves.mp3" />
</winter-audio-player>

Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do
eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim
ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut
aliquip ex ea commodo consequat. Duis aute irure dolor in
reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla
pariatur. Excepteur sint occaecat cupidatat non proident, sunt in
culpa qui officia deserunt mollit anim id est laborum

<winter-audio-player
    title="Ramp wave with filter"
    src="https://storage.googleapis.com/files.winterbloom.com/gemini/ramp_filtered.mp3"
    loop></winter-audio-player>

## Carousel

<winter-carousel>
    <img src="../images/17-hardware-pot-nuts-1.webp" />
    <img src="../images/17-hardware-pot-nuts-2.webp" />
    <img src="../images/17-hardware-pot-nuts-3.webp" />
    <img src="../images/17-hardware-pot-nuts-4.webp" />
    <img src="../images/17-hardware-pot-nuts-5.webp" />
    <img src="../images/17-hardware-pot-nuts-6.webp" />
    <img src="../images/17-hardware-pot-nuts-7.webp" />
    <img src="../images/17-hardware-pot-nuts-8.webp" />
</winter-carousel>

## Image map

<winter-image-map src="../images/kit-contents.svg">
    <winter-image-map-item id="mainboard">
    Mainboard
    </winter-image-map-item>
    <winter-image-map-item id="faceplate">
    Faceplate
    </winter-image-map-item>
    <winter-image-map-item id="jacks">
    1/8" jacks (8)
    </winter-image-map-item>
    <winter-image-map-item id="jack-nuts">
    Hex nuts for the 1/8" jacks (8)
    </winter-image-map-item>
    <winter-image-map-item id="power-header">
    Eurorack power header
    </winter-image-map-item>
    <winter-image-map-item id="rubber-bands">
    Rubber bands (2)
    </winter-image-map-item>
    <winter-image-map-item id="big-knob">
    Big knob
    </winter-image-map-item>
    <winter-image-map-item id="small-knob">
    Small knobs (3)
    </winter-image-map-item>
    <winter-image-map-item id="trimpots">
    Tall trimmer pots (3)
    </winter-image-map-item>
    <winter-image-map-item id="pots">
    9mm pots (4)
    </winter-image-map-item>
    <winter-image-map-item id="pot-washers">
    Washers for 9mm pots (4)
    </winter-image-map-item>
    <winter-image-map-item id="pot-nuts">
    Nuts for 9mm pots (4)
    </winter-image-map-item>
</winter-image-map>
